@@ -58,6 +58,7 @@ class JsonObject:
                 s += "%s" % str(i)
         return "{%s}" % s
 
+
     def get_numeric_values(self):
         values = JsonList()
         for k in self.get_numeric_columns():
@@ -82,6 +83,14 @@ class JsonObject:
                     columns.append(v)
         return columns
 
+    def into(self, cls: type):
+        if not issubclass(cls, JsonObject):
+            raise RuntimeError("type must derive from JsonObject")
+        nv = cls()
+        for c in self.get_columns():
+            nv[c] = self[c]
+        return nv
+
     def get_columns(self):
         columns = JsonList(list_type=str)
         for v in self.get_members():
@@ -316,13 +325,14 @@ class JsonList(list):
         newclass = type(list_type_name, (JsonList,), {"__init__": __init__})
         return newclass
 
+
     def _typeCheck(self, val):
         if val is None and self.allow_empty:
             return
         if self.list_type:
             if self.list_type is float and type(val) is int: #json ints can also be floats
                 val = float(val)
-            check_type(val, self.list_type, "Wrong type %s, this list can hold only instances of %s" % (type(val), str(self.list_type)))
+            check_type(val, self.list_type, "Wrong type %s, this list can hold only instances of %s" % (type(val) % str(self.list_type)))
         else:
             if not (issubclass(type(val), JsonObject) or isinstance(val, (str, int, float, bool, JsonList))):
                 raise TypeError("Wrong type %s, this list can hold only str, int, float, bool, JsonObject or JsonList" % (type(val),))
